@@ -87,8 +87,7 @@ COMPARISON_OPERATORS = {
 ASSIGNMENT_EXPRESSIONS = {
     "increase": increase,
     "decrease": decrease,
-    "assign": assign,
-    "=": assign
+    "assign": assign
 }
 
 NUMERICAL_BINARY_OPERATORS = {
